RxImage class

Inheritance

Constructors

RxImage({Key? key, required RxCacheImageProvider image, required String imageUrl, RxCacheManagerMixing? cacheManager, String? cacheKey, ValueChanged<Object>? errorListener, double? width, double? height, BoxFit? fit, BoxFit? placeholderFit, Color? color, bool gaplessPlayback = false, ImageErrorWidgetBuilder? errorBuilder, Animation<double>? opacity, BlendMode? colorBlendMode, FilterQuality filterQuality = FilterQuality.low, Alignment alignment = Alignment.center, ImageRepeat repeat = ImageRepeat.noRepeat, bool matchTextDirection = false, Rect? centerSlice, bool isAntiAlias = false, bool excludeFromSemantics = false, String? semanticLabel, ImageLoadingBuilder? loadingBuilder, int? cacheHeight, int? cacheWidth})
const
RxImage.cacheNetwork({Key? key, required String? url, Map<String, String>? headers, RxCacheManagerMixing? cacheManager, double scale = 1.0, String? mCacheKey, ValueChanged<Object>? mErrorListener, double? width, double? height, BoxFit? fit, BoxFit? placeholderFit, Color? color, bool gaplessPlayback = false, ImageErrorWidgetBuilder? errorBuilder, Animation<double>? opacity, BlendMode? colorBlendMode, FilterQuality filterQuality = FilterQuality.low, Alignment alignment = Alignment.center, ImageRepeat repeat = ImageRepeat.noRepeat, bool matchTextDirection = false, Rect? centerSlice, bool isAntiAlias = false, bool excludeFromSemantics = false, String? semanticLabel, ImageLoadingBuilder? loadingBuilder, int? cacheHeight, int? cacheWidth})

Properties

alignment Alignment
How to align the image within its bounds.
final
cacheHeight int?
final
cacheKey String?
The target image's cache key.
final
cacheManager → RxCacheManagerMixing?
Option to use cacheManager with other settings
final
cacheWidth int?
final
centerSlice Rect?
The center slice for a nine-patch image.
final
color Color?
If non-null, this color is blended with each image pixel using colorBlendMode.
final
colorBlendMode BlendMode?
Used to combine color with this image.
final
errorBuilder ImageErrorWidgetBuilder?
A builder function that is called if an error occurs during image loading.
final
errorListener ValueChanged<Object>?
Listener to be called when images fails to load.
final
excludeFromSemantics bool
Whether to exclude this image from semantics.
final
filterQuality FilterQuality
The rendering quality of the image.
final
fit BoxFit?
How to inscribe the image into the space allocated during layout.
final
gaplessPlayback bool
Whether to continue showing the old image (true), or briefly show nothing (false), when the image provider changes. The default value is false.
final
hashCode int
The hash code for this object.
no setterinherited
height double?
If non-null, require the image to have this height.
final
image RxCacheImageProvider
The image to display.
final
imageUrl String
The target image that is displayed.
final
isAntiAlias bool
Whether to paint the image with anti-aliasing.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBuilder ImageLoadingBuilder?
final
matchTextDirection bool
Whether to paint the image in the direction of the TextDirection.
final
opacity Animation<double>?
If non-null, the value from the Animation is multiplied with the opacity of each image pixel before painting onto the canvas.
final
placeholderFit BoxFit?
How to inscribe the placeholder image into the space allocated during layout.
final
repeat ImageRepeat
How to paint any portions of the layout bounds not covered by the image.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
A Semantic description of the image.
final
width double?
If non-null, require the image to have this width.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<RxImage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited